package com.ruoyi.weighbridge.mapper;

import java.util.List;
import com.ruoyi.common.core.domain.entity.DibangCar;

/**
 * 车辆Mapper接口
 * 
 * @author liuhj
 * @date 2022-03-10
 */
public interface DibangCarMapper 
{
    /**
     * 查询车辆
     * 
     * @param carId 车辆主键
     * @return 车辆
     */
    public DibangCar selectDibangCarByCarId(String carId);

    /**
     * 查询车辆列表
     * 
     * @param dibangCar 车辆
     * @return 车辆集合
     */
    public List<DibangCar> selectDibangCarList(DibangCar dibangCar);

    /**
     * 新增车辆
     * 
     * @param dibangCar 车辆
     * @return 结果
     */
    public int insertDibangCar(DibangCar dibangCar);

    /**
     * 修改车辆
     * 
     * @param dibangCar 车辆
     * @return 结果
     */
    public int updateDibangCar(DibangCar dibangCar);

    /**
     * 删除车辆
     * 
     * @param carId 车辆主键
     * @return 结果
     */
    public int deleteDibangCarByCarId(String carId);

    /**
     * 批量删除车辆
     * 
     * @param carIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDibangCarByCarIds(String[] carIds);

    /**
     * 根据车牌号查询车辆
     *
     * @param plateNo 车牌号
     * @return 结果
     */
    public DibangCar selectDibangCarByPlateNo(String plateNo);
}
